#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ixset-typed
version:              0.5.1.0
visibility:           public
id:                   ixset-typed-0.5.1.0-KFwjHZ0QCRQ7el2eFATBVb
key:                  ixset-typed-0.5.1.0-KFwjHZ0QCRQ7el2eFATBVb
license:              BSD-3-Clause
maintainer:           Andres Löh <andres@well-typed.com>
author:               Andres Löh, Happstack team, HAppS LLC
synopsis:             Efficient relational queries on Haskell sets.
description:
    This Haskell package provides a data structure of sets that are indexed
    by potentially multiple indices.

    Sets can be created, modified, and queried in various ways.

    The package is a variant of the <https://hackage.haskell.org/package/ixset ixset>
    package. The ixset package makes use
    of run-time type information to find a suitable index on a query, resulting
    in possible run-time errors when no suitable index exists. In ixset-typed,
    the types of all indices available or tracked in the type system.
    Thus, ixset-typed should be safer to use than ixset, but in turn requires
    more GHC extensions.

    At the moment, the two packages are relatively compatible. As a consequence
    of the more precise types, a few manual tweaks are necessary when switching
    from one to the other, but the interface is mostly the same.

category:             Data Structures
abi:                  2fa755d3f334eab9bf6f3d132c272e4f
exposed:              True
exposed-modules:      Data.IxSet.Typed Data.IxSet.Typed.Ix
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ixset-typed-0.5.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ixset-typed-0.5.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ixset-typed-0.5.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ixset-typed
hs-libraries:         HSixset-typed-0.5.1.0-KFwjHZ0QCRQ7el2eFATBVb
depends:
    base-4.18.2.1 containers-0.6.7 deepseq-1.4.8.1
    safecopy-0.10.4.3-2srlMJ7KQV93q9abZ2UqjB
    syb-0.7.3-8aDoibIh418LOq04kgZkPM template-haskell-2.20.0.0

haddock-interfaces:   /usr/share/doc/haskell-ixset-typed/html/ixset-typed.haddock
haddock-html:         /usr/share/doc/haskell-ixset-typed/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

